# User Roles and Permissions
### On this page
  * [User Roles](https://help.sap.com/docs/leanix/ea/user-roles-and-permissions#user-roles)
  * [Standard User Roles](https://help.sap.com/docs/leanix/ea/user-roles-and-permissions#standard-user-roles)
  * [Custom User Roles](https://help.sap.com/docs/leanix/ea/user-roles-and-permissions#custom-user-roles)
  * [Creating Custom User Roles](https://help.sap.com/docs/leanix/ea/user-roles-and-permissions#creating-custom-user-roles)
  * [Role-Based Permissions](https://help.sap.com/docs/leanix/ea/user-roles-and-permissions#role-based-permissions)
  * [Configuring Role-Based Permissions](https://help.sap.com/docs/leanix/ea/user-roles-and-permissions#configuring-role-based-permissions)


Adjust role-based permissions and define custom roles.
In the User Roles and Permissions section of the administration area, you can:
  * Create custom user roles — if you’re managing roles within your single sign-on (SSO) identity provider (IdP)
  * Edit translations for user roles
  * Modify role-based permissions unrelated to fact sheets
